@@ -3,13 +3,13 @@
 #'   initialized clock_models objects
 #' @return TRUE if x, or all elements of x, are initialized clock_model objects
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 are_init_clock_models <- function(
   x
 ) {
-  if (!are_clock_models(x)) return(FALSE) # nolint beautier function
+  if (!beautier::are_clock_models(x)) return(FALSE)
   for (i in x) {
-    if (!is_init_clock_model(i)) return(FALSE) # nolint beautier function call
+    if (!beautier::is_init_clock_model(i)) return(FALSE)
   }
   TRUE
 }
