@@ -1,3 +1,5 @@
+#' Internal function
+#'
 #' Creates the clock model's XML for the tracelog section
 #' @inheritParams default_params_doc
 #' @return a character vector of XML strings
@@ -10,16 +12,24 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 clock_model_to_xml_tracelog <- function(
-  clock_model,
-  mrca_priors = NA
+  inference_model,
+  clock_model = "deprecated",
+  mrca_priors = "deprecated"
 ) {
+  testthat::expect_equal(clock_model, "deprecated")
+  testthat::expect_equal(mrca_priors, "deprecated")
+  # Do not be smart yet
+  clock_model <- inference_model$clock_model
+  mrca_priors  <- list(inference_model$mrca_prior)
+
   testit::assert(beautier::is_clock_model(clock_model))
   id <- clock_model$id
   testit::assert(beautier::is_id(id))
 
   text <- NULL
-  if (beautier::is_rln_clock_model(clock_model)) {
-    if (beautier::is_mrca_prior_with_distr(mrca_priors[[1]])
+  if (beautier::is_rln_clock_model(inference_model$clock_model)) {
+    if (beautier::has_mrca_prior_with_distr(inference_model) ||
+        beautier::has_tip_dating(inference_model)
     ) {
       text <- c(text, paste0("<log idref=\"ucldMean.c:", id, "\"/>")) # nolint this is no absolute path
     }
