@@ -1,4 +1,6 @@
-#' Represent the clock models as XML
+#' Deprecated function
+#'
+#' Internal function to represent the clock models as XML
 #' @examples
 #'  # <distribution id="posterior" spec="util.CompoundDistribution">
 #'  #     <distribution id="prior" spec="util.CompoundDistribution">
@@ -12,22 +14,9 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 clock_models_to_xml_prior_distr <- function( # nolint indeed long function name
-  clock_models,
-  mrca_priors = NA,
-  tipdates_filename = NA
+  clock_models = "deprecated",
+  mrca_priors = "deprecated",
+  tipdates_filename = "deprecated"
 ) {
-  text <- NULL
-
-  for (i in seq_along(clock_models)) {
-    clock_model <- clock_models[[i]]
-    text <- c(
-      text,
-      beautier::clock_model_to_xml_prior_distr(
-        clock_model = clock_model,
-        mrca_priors = mrca_priors,
-        tipdates_filename = tipdates_filename
-      )
-    )
-  }
-  text
+  stop("deprecated, use beautier::clock_model_to_xml_prior_distr")
 }
