@@ -4,7 +4,7 @@
 #' @export
 create_temp_tracelog_filename <- function() {
   normalizePath(
-    get_beautier_tempfilename(
+    beautier::get_beautier_tempfilename(
       pattern = "tracelog_",
       fileext = ".log"
     ),
