@@ -19,9 +19,11 @@
 #'   testit::assert(created == expected)
 #' @export
 get_alignment_ids <- function(filenames) {
-  if (are_fasta_filenames(filenames)) {
+  if (beautier::are_fasta_filenames(filenames)) {
     return(
-      get_alignment_ids_from_fasta_filenames(fasta_filenames = filenames)
+      beautier::get_alignment_ids_from_fasta_filenames(
+        fasta_filenames = filenames
+      )
     )
   }
 }
