@@ -14,7 +14,7 @@ fasta_filename <- get_beautier_path("test_output_0.fas")
 image(ape::read.FASTA(fasta_filename))
 
 ## ----create_output_filename---------------------------------------------------
-output_filename <- tempfile(pattern = "beast2", fileext = ".xml")
+output_filename <- get_beautier_tempfilename()
 output_filename
 
 ## ----create_beast2_input_file-------------------------------------------------
@@ -26,3 +26,6 @@ create_beast2_input_file(
 ## ----show_beast2_input_file---------------------------------------------------
 readLines(output_filename)
 
+## ----cleanup------------------------------------------------------------------
+file.remove(output_filename)
+
